.. Pyslet documentation master file, created by
   sphinx-quickstart on Tue Jun 14 08:06:51 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Contents
========

.. toctree::
   :maxdepth: 1
   :numbered:
   
   whatsnew
   compatibility
   ims
   odatav2
   http
   general

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: ../README.rst


Format of the Documentation
---------------------------

The documentation has been written using ReStructuredText, a simple
format created as part of the docutils package on SourceForge.  The
documentation files you are most likely reading have been generated
using Sphinx.  Parts of the documentation are auto-generated from the
Python source files to make it easier to automatically discover the
documentation using other tools capable of reading Python docstrings. 
However, this requires that the docstrings be written using
ReStructuredText too, which means there is some additional markup for
python-cross referencing in the code that may not be interpretable by
other system (see below for details).

*   ReStructuredText Primer:
    http://docutils.sourceforge.net/docs/user/rst/quickstart.html   
    
    -   Quick Reference:
        http://docutils.sourceforge.net/docs/user/rst/quickref.html
    
    -   Sphinx: http://sphinx.pocoo.org/
    
        +   Autodoc externsion: http://sphinx.pocoo.org/ext/autodoc.html

        +   Python-cross references:
            http://sphinx.pocoo.org/domains.html#python-roles



